@@ -97,7 +97,7 @@ def _compute_line_flux(spectrum, regions=None):
         calc_spectrum = spectrum
 
     # Average dispersion in the line region
-    avg_dx = np.diff(calc_spectrum.spectral_axis)
+    avg_dx = np.abs(np.diff(calc_spectrum.spectral_axis.quantity))
 
     line_flux = np.sum(calc_spectrum.flux[1:] * avg_dx)
 
@@ -115,17 +115,19 @@ def _compute_equivalent_width(spectrum, continuum=1, regions=None):
     if continuum == 1:
         continuum = 1*calc_spectrum.flux.unit
 
-    spectral_axis = calc_spectrum.spectral_axis
-    dx = spectral_axis[-1] - spectral_axis[0]
+    spectral_axis = calc_spectrum.spectral_axis.quantity
 
+    # Ensure that the
+    dx = np.abs(spectral_axis[-1] - spectral_axis[0])
 
     line_flux = _compute_line_flux(spectrum, regions)
 
     # Calculate equivalent width
-    ew =  dx - (line_flux / continuum)
+    ew = dx - (line_flux / continuum)
 
     return ew.to(calc_spectrum.spectral_axis.unit)
 
+
 def is_continuum_below_threshold(spectrum, threshold=0.01):
     """
     Determine if the baseline of this spectrum is less than a threshold.
@@ -180,6 +182,7 @@ def is_continuum_below_threshold(spectrum, threshold=0.01):
     else:
         return np.median(flux) / mad_std(flux) < threshold
 
+
 def warn_continuum_below_threshold(threshold=0.01):
     """
     Decorator for methods that should warn if the baseline
